@@ -1,5 +1,6 @@
 /*
- * LALStochasticVCSInfo.h - LALStochastic VCS Information Header
+ * Copyright (C) 2014, 2016 Karl Wette
+ * Copyright (C) 2009-2013 Adam Mercer
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +16,10 @@
  * along with with program; see the file COPYING. If not, write to the
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  * MA 02111-1307 USA
- *
- * Copyright (C) 2009-2013 Adam Mercer
- * Copyright (C) 2014 Karl Wette
+ */
+
+/*
+ * LALStochasticVCSInfo.h - LALStochastic VCS Information Header
  */
 
 /** \cond DONT_DOXYGEN */
@@ -33,37 +35,19 @@
 extern "C" {
 #endif
 
-/* VCS information defines */
-#define LALSTOCHASTIC_NAME "LALStochastic"
-#define LALSTOCHASTIC_VCS_ID "4fb4d1fc153c792c62434c22228446af38913c75"
-#define LALSTOCHASTIC_VCS_DATE "2016-10-10 17:31:35 +0000"
+/* VCS information */
+#define LALSTOCHASTIC_VCS_ID "983bcce6cab260b3a08bae6f7076d8007b8990db"
+#define LALSTOCHASTIC_VCS_DATE "2017-02-6 18:17:17 +0000"
 #define LALSTOCHASTIC_VCS_BRANCH "None"
-#define LALSTOCHASTIC_VCS_TAG "lalstochastic-v1.1.19"
+#define LALSTOCHASTIC_VCS_TAG "lalstochastic-v1.1.20"
 #define LALSTOCHASTIC_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
 #define LALSTOCHASTIC_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
+#define LALSTOCHASTIC_VCS_CLEAN "CLEAN"
 #define LALSTOCHASTIC_VCS_STATUS "CLEAN: All modifications committed"
 
-/* Identable VCS information defines */
-#define LALSTOCHASTIC_VCS_IDENT_ID "$" "LALStochasticId: 4fb4d1fc153c792c62434c22228446af38913c75 " "$"
-#define LALSTOCHASTIC_VCS_IDENT_DATE "$" "LALStochasticDate: 2016-10-10 17:31:35 +0000 " "$"
-#define LALSTOCHASTIC_VCS_IDENT_BRANCH "$" "LALStochasticBranch: None " "$"
-#define LALSTOCHASTIC_VCS_IDENT_TAG "$" "LALStochasticTag: lalstochastic-v1.1.19 " "$"
-#define LALSTOCHASTIC_VCS_IDENT_AUTHOR "$" "LALStochasticAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALSTOCHASTIC_VCS_IDENT_COMMITTER "$" "LALStochasticCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALSTOCHASTIC_VCS_IDENT_STATUS "$" "LALStochasticStatus: CLEAN: All modifications committed " "$"
-
-/* Header VCS information structure */
-static const LALVCSInfo lalStochasticVCSInfoHeader = { \
-  LALSTOCHASTIC_NAME, \
-  LALSTOCHASTIC_VERSION, \
-  LALSTOCHASTIC_VCS_ID, \
-  LALSTOCHASTIC_VCS_DATE, \
-  LALSTOCHASTIC_VCS_BRANCH, \
-  LALSTOCHASTIC_VCS_TAG, \
-  LALSTOCHASTIC_VCS_AUTHOR, \
-  LALSTOCHASTIC_VCS_COMMITTER, \
-  LALSTOCHASTIC_VCS_STATUS \
-};
+/* VCS header/library mismatch link check function */
+#define LALSTOCHASTIC_VCS_LINK_CHECK LALSTOCHASTIC_CLEAN_983bcce6cab260b3a08bae6f7076d8007b8990db_VCS_HEADER_LIBRARY_MISMATCH
+void LALSTOCHASTIC_VCS_LINK_CHECK(void);
 
 #ifdef __cplusplus
 }
@@ -72,7 +56,3 @@ static const LALVCSInfo lalStochasticVCSInfoHeader = { \
 #endif /* _LALSTOCHASTICVCSINFOHEADER_H */
 
 /** \endcond */
-
-/*
- * vim: tw=0 ts=2 et
- */
